@@ -23,26 +23,34 @@ from tacker.api.v1 import resource_helper
 from tacker.common import exceptions
 from tacker.openstack.common import log as logging
 from tacker.plugins.common import constants
-from tacker.services.service_base import NFVPluginBase
+from tacker.services import service_base
 
 
 LOG = logging.getLogger(__name__)
 
 
 class InfraDriverNotSpecified(exceptions.InvalidInput):
-    message = _('infra driver is not speicfied')
+    message = _('infra driver is not specified')
+
+
+class MGMTDriverNotSpecified(exceptions.InvalidInput):
+    message = _('mgmt driver is not specified')
+
+
+class MultipleMGMTDriversSpecified(exceptions.InvalidInput):
+    message = _('More than one MGMT Driver per template is not supported')
 
 
 class ServiceTypesNotSpecified(exceptions.InvalidInput):
-    message = _('service types are not speicfied')
+    message = _('service types are not specified')
 
 
 class DeviceTemplateInUse(exceptions.InUse):
-    message = _('device template %(device_template_id)s is still in use')
+    message = _('VNFD %(device_template_id)s is still in use')
 
 
 class DeviceInUse(exceptions.InUse):
-    message = _('Device %(device_id)s is still in use')
+    message = _('VNF %(device_id)s is still in use')
 
 
 class InvalidInfraDriver(exceptions.InvalidInput):
@@ -54,48 +62,43 @@ class InvalidServiceType(exceptions.InvalidInput):
 
 
 class DeviceCreateFailed(exceptions.TackerException):
-    message = _('creating device based on %(device_template_id)s failed')
+    message = _('creating VNF based on %(device_template_id)s failed')
 
 
 class DeviceCreateWaitFailed(exceptions.TackerException):
-    message = _('waiting for creation of device %(device_id)s failed')
+    message = _('waiting for creation of VNF %(device_id)s failed')
 
 
 class DeviceDeleteFailed(exceptions.TackerException):
-    message = _('deleting device %(device_id)s failed')
+    message = _('deleting VNF %(device_id)s failed')
 
 
 class DeviceTemplateNotFound(exceptions.NotFound):
-    message = _('device template %(device_tempalte_id)s could not be found')
+    message = _('VNFD template %(device_tempalte_id)s could not be found')
 
 
-class SeviceTypeNotFound(exceptions.NotFound):
+class ServiceTypeNotFound(exceptions.NotFound):
     message = _('service type %(service_type_id)s could not be found')
 
 
 class DeviceNotFound(exceptions.NotFound):
-    message = _('device %(device_id)s could not be found')
-
-
-class ServiceInstanceNotManagedByUser(exceptions.InUse):
-    message = _('service instance %(service_instance_id)s is '
-                'managed by other service')
-
-
-class ServiceInstanceInUse(exceptions.InUse):
-    message = _('service instance %(service_instance_id)s is still in use')
-
-
-class ServiceInstanceNotFound(exceptions.NotFound):
-    message = _('service instance %(service_instance_id)s could not be found')
+    message = _('VNF %(device_id)s could not be found')
 
 
 class ParamYAMLNotWellFormed(exceptions.InvalidInput):
     message = _("Parameter YAML not well formed - %(error_msg_details)s")
 
 
+class ToscaParserFailed(exceptions.InvalidInput):
+    message = _("tosca-parser failed: - %(error_msg_details)s")
+
+
+class HeatTranslatorFailed(exceptions.InvalidInput):
+    message = _("heat-translator failed: - %(error_msg_details)s")
+
+
 class InputValuesMissing(exceptions.InvalidInput):
-    message = _("Input values missing for 'get_input")
+    message = _("Parameter input values missing for the key '%(key)s'")
 
 
 class ParamYAMLInputMissing(exceptions.InvalidInput):
@@ -114,6 +117,27 @@ class IPAddrInvalidInput(exceptions.InvalidInput):
     message = _("IP Address input values should be in a list format")
 
 
+class HugePageSizeInvalidInput(exceptions.InvalidInput):
+    message = _("Value specified for mem_page_size is invalid:"
+                "%(error_msg_details)s. The valid values are 'small', 'large',"
+                "'any' or an integer value in MB")
+
+
+class CpuAllocationInvalidKeys(exceptions.InvalidInput):
+    message = _("Invalid keys specified in VNFD - %(error_msg_details)s."
+                "Supported keys are: %(valid_keys)s")
+
+
+class NumaNodesInvalidKeys(exceptions.InvalidInput):
+    message = _("Invalid keys specified in VNFD - %(error_msg_details)s."
+                "Supported keys are: %(valid_keys)s")
+
+
+class FilePathMissing(exceptions.InvalidInput):
+    message = _("'file' attribute is missing for "
+                "tosca.artifacts.Deployment.Image.VM artifact type")
+
+
 def _validate_service_type_list(data, valid_values=None):
     if not isinstance(data, list):
         msg = _("invalid data format for service list: '%s'") % data
@@ -135,30 +159,8 @@ def _validate_service_type_list(data, valid_values=None):
             return msg
 
 
-def _validate_service_context_list(data, valid_values=None):
-    if not isinstance(data, list):
-        msg = _("invalid data format for service context list: '%s'") % data
-        LOG.debug(msg)
-        return msg
-
-    key_specs = {
-        'network_id': {'type:uuid': None},
-        'subnet_id': {'type:uuid': None},
-        'port_id': {'type:uuid': None},
-        'router_id': {'type:uuid': None},
-        'role': {'type:string': None},
-        'index': {'type:non_negative': None,
-                  'convert_to': attr.convert_to_int},
-    }
-    for sc_entry in data:
-        msg = attr._validate_dict_or_empty(sc_entry, key_specs=key_specs)
-        if msg:
-            LOG.debug(msg)
-            return msg
-
-
 attr.validators['type:service_type_list'] = _validate_service_type_list
-attr.validators['type:service_context_list'] = _validate_service_context_list
+
 
 RESOURCE_ATTRIBUTE_MAP = {
 
@@ -244,135 +246,13 @@ RESOURCE_ATTRIBUTE_MAP = {
             'validate': {'type:uuid': None},
             'is_visible': True,
         },
-        'name': {
+        'vim_id': {
             'allow_post': True,
-            'allow_put': True,
+            'allow_put': False,
             'validate': {'type:string': None},
             'is_visible': True,
             'default': '',
         },
-        'description': {
-            'allow_post': True,
-            'allow_put': True,
-            'validate': {'type:string': None},
-            'is_visible': True,
-            'default': '',
-        },
-        'instance_id': {
-            'allow_post': False,
-            'allow_put': False,
-            'validate': {'type:string': None},
-            'is_visible': True,
-        },
-        'mgmt_url': {
-            'allow_post': False,
-            'allow_put': False,
-            'validate': {'type:string': None},
-            'is_visible': True,
-        },
-        'attributes': {
-            'allow_post': True,
-            'allow_put': True,
-            'validate': {'type:dict_or_none': None},
-            'is_visible': True,
-            'default': {},
-        },
-        'service_contexts': {
-            'allow_post': True,
-            'allow_put': False,
-            'validate': {'type:service_context_list': None},
-            'is_visible': True,
-            'default': [],
-        },
-        'status': {
-            'allow_post': False,
-            'allow_put': False,
-            'is_visible': True,
-        },
-    },
-
-    'device_templates': {
-        'id': {
-            'allow_post': False,
-            'allow_put': False,
-            'validate': {'type:uuid': None},
-            'is_visible': True,
-            'primary_key': True,
-        },
-        'tenant_id': {
-            'allow_post': True,
-            'allow_put': False,
-            'validate': {'type:string': None},
-            'required_by_policy': True,
-            'is_visible': True,
-        },
-        'name': {
-            'allow_post': True,
-            'allow_put': True,
-            'validate': {'type:string': None},
-            'is_visible': True,
-            'default': '',
-        },
-        'description': {
-            'allow_post': True,
-            'allow_put': True,
-            'validate': {'type:string': None},
-            'is_visible': True,
-            'default': '',
-        },
-        'service_types': {
-            'allow_post': True,
-            'allow_put': False,
-            'convert_to': attr.convert_to_list,
-            'validate': {'type:service_type_list': None},
-            'is_visible': True,
-            'default': attr.ATTR_NOT_SPECIFIED,
-        },
-        'infra_driver': {
-            'allow_post': True,
-            'allow_put': False,
-            'validate': {'type:string': None},
-            'is_visible': True,
-            'default': attr.ATTR_NOT_SPECIFIED,
-        },
-        'mgmt_driver': {
-            'allow_post': True,
-            'allow_put': False,
-            'validate': {'type:string': None},
-            'is_visible': True,
-            'default': attr.ATTR_NOT_SPECIFIED,
-        },
-        'attributes': {
-            'allow_post': True,
-            'allow_put': False,
-            'convert_to': attr.convert_none_to_empty_dict,
-            'validate': {'type:dict_or_nodata': None},
-            'is_visible': True,
-            'default': None,
-        },
-    },
-
-    'devices': {
-        'id': {
-            'allow_post': False,
-            'allow_put': False,
-            'validate': {'type:uuid': None},
-            'is_visible': True,
-            'primary_key': True
-        },
-        'tenant_id': {
-            'allow_post': True,
-            'allow_put': False,
-            'validate': {'type:string': None},
-            'required_by_policy': True,
-            'is_visible': True
-        },
-        'template_id': {
-            'allow_post': True,
-            'allow_put': False,
-            'validate': {'type:uuid': None},
-            'is_visible': True,
-        },
         'name': {
             'allow_post': True,
             'allow_put': True,
@@ -406,12 +286,12 @@ RESOURCE_ATTRIBUTE_MAP = {
             'is_visible': True,
             'default': {},
         },
-        'service_contexts': {
+        'placement_attr': {
             'allow_post': True,
             'allow_put': False,
-            'validate': {'type:service_context_list': None},
+            'validate': {'type:dict_or_none': None},
             'is_visible': True,
-            'default': [],
+            'default': {},
         },
         'status': {
             'allow_post': False,
@@ -449,7 +329,6 @@ class Vnfm(extensions.ExtensionDescriptor):
         plural_mappings = resource_helper.build_plural_mappings(
             special_mappings, RESOURCE_ATTRIBUTE_MAP)
         plural_mappings['service_types'] = 'service_type'
-        plural_mappings['service_contexts'] = 'service_context'
         attr.PLURALS.update(plural_mappings)
         return resource_helper.build_resource_info(
             plural_mappings, RESOURCE_ATTRIBUTE_MAP, constants.VNFM,
@@ -469,7 +348,7 @@ class Vnfm(extensions.ExtensionDescriptor):
 
 
 @six.add_metaclass(abc.ABCMeta)
-class VNFMPluginBase(NFVPluginBase):
+class VNFMPluginBase(service_base.NFVPluginBase):
     def get_plugin_name(self):
         return constants.VNFM
 
@@ -515,40 +394,3 @@ class VNFMPluginBase(NFVPluginBase):
     @abc.abstractmethod
     def delete_vnf(self, context, vnf_id):
         pass
-
-    @abc.abstractmethod
-    def create_device_template(self, context, device_template):
-        pass
-
-    @abc.abstractmethod
-    def delete_device_template(self, context, device_template_id):
-        pass
-
-    @abc.abstractmethod
-    def get_device_template(self, context, device_template_id, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def get_device_templates(self, context, filters=None, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def get_devices(self, context, filters=None, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def get_device(self, context, device_id, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def create_device(self, context, device):
-        pass
-
-    @abc.abstractmethod
-    def update_device(
-            self, context, device_id, device):
-        pass
-
-    @abc.abstractmethod
-    def delete_device(self, context, device_id):
-        pass
