@@ -22,6 +22,7 @@ import itertools
 import re
 
 from oslo_config import cfg
+import six
 
 from tacker.api.v1 import attributes
 from tacker.common import exceptions
@@ -92,8 +93,8 @@ def _set_rules(data):
     for pol in policies.keys():
         if any([pol.startswith(depr_pol) for depr_pol in
                 DEPRECATED_POLICY_MAP.keys()]):
-            LOG.warn(_("Found deprecated policy rule:%s. Please consider "
-                       "upgrading your policy configuration file"), pol)
+            LOG.warning(_("Found deprecated policy rule:%s. Please consider "
+                          "upgrading your policy configuration file"), pol)
             pol_name, action = pol.rsplit(':', 1)
             try:
                 new_actions = DEPRECATED_ACTION_MAP[action]
@@ -134,8 +135,8 @@ def _build_subattr_match_rule(attr_name, attr, action, target):
     validate = attr['validate']
     key = filter(lambda k: k.startswith('type:dict'), validate.keys())
     if not key:
-        LOG.warn(_("Unable to find data type descriptor for attribute %s"),
-                 attr_name)
+        LOG.warning(_("Unable to find data type descriptor for attribute %s"),
+                    attr_name)
         return
     data = validate[key[0]]
     if not isinstance(data, dict):
@@ -280,7 +281,7 @@ class OwnerCheck(policy.Check):
                     LOG.exception(_('Policy check error while calling %s!'), f)
         match = self.match % target
         if self.kind in creds:
-            return match == unicode(creds[self.kind])
+            return match == six.text_type(creds[self.kind])
         return False
 
 
@@ -395,7 +396,9 @@ def _extract_roles(rule, roles):
 
 
 def get_admin_roles():
-    """Return a list of roles which are granted admin rights according
+    """Get Admin roles.
+
+    Return a list of roles which are granted admin rights according
     to policy settings.
     """
     # NOTE(salvatore-orlando): This function provides a solution for
